==> IceWarpServer-9.1.0_RHEL5.tar.gz: html/webmail/client/inc/frm_autoresponder.js <==
_me = frm_autoresponder.prototype;
function frm_autoresponder(){};

_me.__constructor = function() {
	var me = this;

	this.u_respond._onchange = function() {
		if (this._value() == '0') {
			me._disabled(true);
		} else {
			me._disabled(false);
		}
	}
	
	this.u_respond._onchange();
}

_me._value = function(aValues) {
	if (Is.Defined(aValues)) {
		loadDataIntoFormOnAccess(this, aValues);
		this.__parseContent(aValues['VALUES']['u_respondercontent']);
		this.u_respond._onchange();
	} else {
		var aReturn = {};
		storeDataFromForm(this, aReturn);
		aReturn['u_respondercontent'] = this.__getContent();
		return aReturn;
	}
}

_me._disabled = function (b) {
	this.u_respondperiod._disabled(b);
	this.x_from._disabled(b);
	this.x_subject._disabled(b);
	this.x_respondercontent._disabled(b);
	this.u_respondonlyiftome._disabled(b);
	this.u_respondbetweenfrom._disabled(b);
	this.u_respondbetweento._disabled(b);
}

_me.__parseContent = function (sContent) {
	var aTmp = sContent.split('\n');
	var aRest = [];
	for (var i in aTmp) 
		if (aTmp[i].substring(0,2) == '$$' && aTmp[i].substr(-2) == '$$') {
			var del,nam,val;
			del = aTmp[i].indexOf(' ',2);
			nam = aTmp[i].substring(2,del);
			val = aTmp[i].substring(del+1,aTmp[i].length - 2);
			switch (nam) {
				case 'setactualfrom':
					this.x_from._value(val);
					break;
					
				case 'setsubject':
					this.x_subject._value(val);
					break;
					
				default:
					aRest.push(aTmp[i]);
					continue;
			}
		} else
			aRest.push(aTmp[i]);

	this.x_respondercontent._value(aRest.join('\n'));
}

_me.__getContent = function (aValues) {
	var s1,s2,sResult = '';
	s1 = this.x_from._value();
	s2 = this.x_subject._value();
	if (s1)
		sResult += '$$setactualfrom ' + s1 + '$$\n';
	if (s2)
		sResult += '$$setsubject ' + s2 + '$$\n';
	sResult += this.x_respondercontent._value();
	return sResult;
}

==> IceWarpServer-9.4.1_RHEL5.tar.gz: html/webmail/client/inc/frm_autoresponder.js <==
_me = frm_autoresponder.prototype;
function frm_autoresponder(){};

_me.__constructor = function() {
	var me = this;

	this.u_respond._onchange = function() {
		var v = this._value(),b = false;
		if (v == '0')
		    b = true;

		if (v == '3')
            me.u_respondperiod._disabled(false);
		else
		    me.u_respondperiod._disabled(true);

		me.x_from._disabled(b);
		me.x_subject._disabled(b);
		me.x_respondercontent._disabled(b);
		me.u_respondonlyiftome._disabled(b);
		me.u_respondbetweenfrom._disabled(b);
		me.u_respondbetweento._disabled(b);
	}
	
	this.u_respond._onchange();
}

_me._value = function(aValues) {
	if (Is.Defined(aValues)) {
		loadDataIntoFormOnAccess(this, aValues);
		this.__parseContent(aValues['VALUES']['u_respondercontent']);
		this.u_respond._onchange();
	} else {
		var aReturn = {};
		storeDataFromForm(this, aReturn);
		aReturn['u_respondercontent'] = this.__getContent();
		return aReturn;
	}
}

_me.__parseContent = function (sContent) {
	var aTmp = sContent.split("\n");
	var aRest = [];

	for (var i in aTmp){
		if (aTmp[i].substring(0,2) == '$$' && aTmp[i].substring(aTmp[i].length-2) == '$$') {
			var del,nam,val;
			del = aTmp[i].indexOf(' ',2);
			nam = aTmp[i].substring(2,del);
			val = aTmp[i].substring(del+1,aTmp[i].length - 2);
			switch (nam) {
				case 'setactualfrom':
					this.x_from._value(val);
					break;
					
				case 'setsubject':
					this.x_subject._value(val);
					break;
					
				default:
					aRest.push(aTmp[i]);
					continue;
			}
		}
		else
			aRest.push(aTmp[i]);
	}

	this.x_respondercontent._value(aRest.join('\n'));
}

_me.__getContent = function (aValues) {
	var s1,s2,sResult = '';
	s1 = this.x_from._value();
	s2 = this.x_subject._value();
	if (s1)
		sResult += '$$setactualfrom ' + s1 + '$$\n';
	if (s2)
		sResult += '$$setsubject ' + s2 + '$$\n';
	sResult += this.x_respondercontent._value();
	return sResult;
}
